@@ -14,7 +14,7 @@ from idmtools.utils.collections import ExperimentParentIterator
 if sys.platform == "win32":
     from win32con import FALSE
 from idmtools.builders import SimulationBuilder
-from idmtools.core import ItemType, EntityContainer, UnknownItemException
+from idmtools.core import ItemType, EntityContainer
 from idmtools.core.platform_factory import Platform
 from idmtools.entities import Suite
 from idmtools.entities.experiment import Experiment
@@ -124,8 +124,8 @@ class TestFilePlatform(unittest.TestCase):
         sim = Simulation(name="my_sim")
         try:
             sim.get_directory()
-        except AttributeError as e:
-            self.assertTrue(f"Simulation id: {sim.id} not found in FilePlatform." in str(e))
+        except RuntimeError as e:
+            self.assertTrue("Simulation missing parent!" in str(e))
 
     def test_get_directory_workitem(self):
         workitem = GenericWorkItem(name="test_workitem")
@@ -382,4 +382,62 @@ class TestFilePlatform(unittest.TestCase):
         file_suite.update_tags({"new_file_suite_tag": "abc"})
         tags = file_suite.get_tags()
         expected_suite_tags = {'name': 'suite_tag', 'idmtools': '123', "new_file_suite_tag": "abc"}
-        self.assertTrue(all(tags.get(k) == v for k, v in expected_suite_tags.items()))
\ No newline at end of file
+        self.assertTrue(all(tags.get(k) == v for k, v in expected_suite_tags.items()))
+
+    def test_duplicate_simulation_not_added_twice(self):
+        exp = Experiment("expB")
+        sim = Simulation("sim1")
+
+        exp.add_simulation(sim)
+        exp.add_simulation(sim)
+
+        assert len(exp.simulations) == 1
+
+    def test_get_directory_for_extra_simulations(self):
+        class setParam:
+            def __init__(self, param):
+                self.param = param
+
+            def __call__(self, simulation, value):
+                return simulation.task.set_parameter(self.param, value)
+
+        task = JSONConfiguredPythonTask(script_path=os.path.join(COMMON_INPUT_PATH, "python", "model1.py"))
+        ts = TemplatedSimulations(base_task=task)
+        builder = SimulationBuilder()
+        builder.add_sweep_definition(setParam("a"), range(2))
+        builder.add_sweep_definition(setParam("b"), range(3))
+        ts.add_builder(builder)
+        experiment = Experiment.from_template(ts, name="test_get_directory_for_extra_simulations")
+        # Lookup experiment directory before run
+        exp_dir = experiment.get_directory()
+        # add extra simulation to experiment
+        extra_sim = Simulation(name="sim1")
+        extra_sim.task = task
+        experiment.add_simulation(extra_sim)
+        # lookup sim directory before run
+        s_dir = extra_sim.get_directory()
+        self.assertTrue(s_dir.resolve().is_relative_to(exp_dir.resolve()))
+        # Create suite after experiment is created
+        suite = Suite(name='My_Suite')
+        # Add experiment to the suite
+        suite.add_experiment(experiment)
+        experiment.run(wait_until_done=False)
+        suite_dir = suite.get_directory()
+        e_dir_final = experiment.get_directory()
+        s_dir_final = extra_sim.get_directory()
+        # Verify experiment directory before run is not created
+        self.assertFalse(exp_dir.exists())
+        # Verify experiment directory after run is not created
+        self.assertTrue(e_dir_final.exists())
+        # Verify experiment dir is in suite directory
+        self.assertTrue(e_dir_final.resolve().is_relative_to(suite_dir.resolve()))
+        # Verify extra sim is in experiment directory
+        self.assertTrue(s_dir_final.resolve().is_relative_to(e_dir_final.resolve()))
+        self.assertTrue(len(experiment.simulations) == 7)
+        # verify there is 7 total sim dirs under experiment dir
+        count = 0
+        for sim in experiment.get_simulations():
+            self.assertTrue(os.path.isdir(os.path.join(experiment.get_directory(), sim.get_directory())))
+            count += 1
+        self.assertEqual(count, 7)
+
